Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/tests/usr.bin/xlint/lint1 tests/lint: fix test for queries o...



details:   https://anonhg.NetBSD.org/src/rev/f03a930b9b77
branches:  trunk
changeset: 369961:f03a930b9b77
user:      rillig <rillig%NetBSD.org@localhost>
date:      Sat Sep 10 13:13:22 2022 +0000

description:
tests/lint: fix test for queries on platforms where char is unsigned

These platforms reported an additional "implicit conversion changes
sign" in lines 105, 105, 118, 122.

diffstat:

 tests/usr.bin/xlint/lint1/queries.c |  6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diffs (22 lines):

diff -r 91959e8dfa64 -r f03a930b9b77 tests/usr.bin/xlint/lint1/queries.c
--- a/tests/usr.bin/xlint/lint1/queries.c       Sat Sep 10 12:39:06 2022 +0000
+++ b/tests/usr.bin/xlint/lint1/queries.c       Sat Sep 10 13:13:22 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: queries.c,v 1.4 2022/08/28 08:41:06 rillig Exp $       */
+/*     $NetBSD: queries.c,v 1.5 2022/09/10 13:13:22 rillig Exp $       */
 # 3 "queries.c"
 
 /*
@@ -93,10 +93,10 @@
 }
 
 unsigned long long
-Q4(char *ptr, int i, unsigned long long ull)
+Q4(signed char *ptr, int i, unsigned long long ull)
 {
        /*
         * The conversion from 'char' to 'int' is done by the integer
         * promotions (C11 6.3.1.1p2), not by the usual arithmetic
         * conversions (C11 6.3.1.8p1).
         */
@@ -93,10 +93,10 @@
 {
        /*
-        * The conversion from 'char' to 'int' is done by the integer
+        * The conversion from 'signed char' to 'int' is done by the integer
         * promotions (C11 6.3.1.1p2), not by the usual arithmetic
         * conversions (C11 6.3.1.8p1).



Home | Main Index | Thread Index | Old Index